
from .instruments.sr865.vxi11interface import Vxi11Interface
from .instruments.sr865.visainterface import VisaInterface

from .instruments.sr865.sr865 import SR865
from .instruments.get_instruments import get_sr865

__version__ = "0.0.3"